@@ -12,9 +12,11 @@ import os.path
 import stat
 import sys
 import time
+import ast
 
 from ddupdate.ddplugin import AddressPlugin, AddressError
 from ddupdate.ddplugin import ServicePlugin, ServiceError
+from ddupdate.ddplugin import IpAddr
 
 # pylint: disable=ungrouped-imports
 if sys.version_info >= (3, 5):
@@ -33,6 +35,7 @@ DEFAULTS = {
     'address-plugin': 'default-if',
     'service-plugin': 'dry-run',
     'loglevel': 'info',
+    'ip-version': 'v4',
     'service-options': None,
     'address-options': None,
     'ip-cache': os.path.join(CACHE_DIR, 'ddupdate'),
@@ -70,7 +73,7 @@ def ip_cache_clear(opts, log):
     os.unlink(path)
 
 
-def ip_cache_data(opts, default=("0.0.0.0", 100000)):
+def ip_cache_data(opts, log, default=(IpAddr(ipv4="0.0.0.0"), 100000)):
     """
     Return an (address, cache age in minute) tuple.
 
@@ -83,16 +86,23 @@ def ip_cache_data(opts, default=("0.0.0.0", 100000)):
     now = time.time()
     delta = math.floor((now - mtime) / 60)
     with open(path) as f:
-        addr = f.read().strip()
-    return addr, delta
+        astr = f.read().strip()
+    try:
+        ll = ast.literal_eval(astr)
+        ip = IpAddr(ipv4=ll[0], ipv6=ll[1])
+    except SyntaxError:
+        log.debug("SyntaxError while reading ip cache.")
+        ip_cache_clear(opts, log)
+        ip, delta = default
+    return ip, delta
 
 
-def ip_cache_set(opts, addr):
-    """Set the cached address to string addr."""
+def ip_cache_set(opts, ip):
+    """Set the cached address to IpAddr ip."""
     path = ip_cache_setup(opts)
-    addr = addr if addr else "0.0.0.0"
+    ip = ip if ip else IpAddr(ipv4="0.0.0.0")
     with open(path, "w") as f:
-        f.write(str(addr))
+        f.write(str(ip))
 
 
 def here(path):
@@ -180,7 +190,7 @@ def get_parser(conf):
         "-v", "--ip-version", metavar='version',
         choices=['all', 'v6', 'v4'],
         help='Ip address version(s) to register (v6, v4, all) [v4]',
-        default='v4')
+        default=conf['ip-version'])
     normals.add_argument(
         "-o", "--service-option", metavar="plugin option",
         help='Service plugin option (enter multiple times if required)',
@@ -226,15 +236,19 @@ def parse_options(conf):
         'debug': logging.DEBUG,
     }
     parser = get_parser(conf)
-    parser.version = "0.6.0"
+    parser.version = "0.6.4"
     opts = parser.parse_args()
     if opts.help == '-':
         parser.print_help()
         raise _GoodbyeError()
     if not opts.address_options:
-        opts.address_options = conf['address-options']
+        opts.address_options = []
+        if conf['address-options']:
+            opts.address_options = conf['address-options'].split()
     if not opts.service_options:
-        opts.service_options = conf['service-options']
+        opts.service_options = []
+        if conf['service-options']:
+            opts.service_options = conf['service-options'].split()
     opts.loglevel = level_by_name[opts.loglevel]
     opts.ip_cache = conf['ip-cache']
     return opts
@@ -430,8 +444,8 @@ def main():
             log.info("Using ip address: %s", ip)
         if opts.force:
             ip_cache_clear(opts, log)
-        addr, age = ip_cache_data(opts)
-        if age < service_plugin.ip_cache_ttl() and (addr == ip or not ip):
+        cached_ip, age = ip_cache_data(opts, log)
+        if age < service_plugin.ip_cache_ttl() and (cached_ip == ip or not ip):
             log.info("Update inhibited, cache is fresh (%d/%d min)",
                      age, service_plugin.ip_cache_ttl())
             raise _GoodbyeError()
